-- If no default action then auto detect the operating system and set a default action accordingly.
if ( _ACTION == nil ) then
    if ( os.is( 'linux' ) ) then
        PLATFORM = 'linux'
        print( 'Auto-action: Linux detected - using gmake' )
        _ACTION = 'gmake'
    elseif ( os.is( 'windows' ) ) then
        
        PLATFORM = 'win32'
        print( 'Auto-action: Windows detected - using vs2010' )
        _ACTION = 'vs2010'
	end
end

-- Beginning of Build Description:
if ( PLATFORM == 'win32' ) then
    CONFIGURATION_FILE = 'configure_win32.lua'
elseif ( PLATFORM == 'linux' ) then
	CONFIGURATION_FILE = 'configure_linux.lua'
end

dofile( CONFIGURATION_FILE ) -- This file should set library/include paths, build preferences, etc

LOCATION_DIR = BUILD_DIR
SRC_DIR = '../src/'

solution 'GLK'
	configurations { 'debug', 'release', 'profile' }
	platforms { 'Native' }-- , 'gnucross' }
	--toolchain ( 'arm-angstrom-linux-gnueabi-' )
	
	location( LOCATION_DIR ) -- Location for make/solution files
    language 'C++'
    flags { 'NoExceptions','NoRTTI','ExtraWarnings','NoPCH' }
	
    includedirs { INC_PATHS }
    includedirs { '../include' }
    libdirs( LIB_PATHS )

	defines ( EXTRA_DEFINES )
	buildoptions ( EXTRA_BUILD_OPTIONS )
    linkoptions ( EXTRA_LINK_OPTIONS )

	configuration 'release'
		targetdir( LOCATION_DIR .. '/release' ) -- Location for compiled executables/libs
		defines { 'NDEBUG' }
		flags { 'OptimizeSpeed','NoFramePointer' }
		
	configuration 'debug'
		targetdir( LOCATION_DIR .. '/debug' ) -- Location for compiled executables/libs
		defines { 'DEBUG', 'LUA_USE_APICHECK' }
		flags { 'Symbols' }
        targetsuffix( '_d' )
        
	configuration 'profile'
		targetdir( LOCATION_DIR .. '/profile' ) -- Location for compiled executables/libs
		defines { 'NDEBUG' }
		flags { 'Symbols', 'OptimizeSpeed' }
        targetsuffix( '_prof' )
        buildoptions( '-pg -fno-omit-frame-pointer -static-libgcc' )
        linkoptions( '-pg' )

    -- The core GLK library contains GUI/OpenGL independent components
	project 'glkcore'
		kind 'SharedLib'
		
		if ( PLATFORM == 'linux' ) then
		    --linkoptions { "-Wl,-soname,glkcore.so.0" }
		end
				
		flags { 'Symbols' }
		
		files {
			SRC_DIR .. 'glkcore/**.cpp',
			SRC_DIR .. 'glkcore/**.h'
		}

		-- need to exclude files which are platform specific
		if ( PLATFORM == 'win32' ) then
			excludes { SRC_DIR .. 'glkcore/io/linux/*', SRC_DIR .. 'glkcore/thread/posix/*' }
			links ( LIBS )
		elseif ( PLATFORM == 'linux' ) then
			excludes { SRC_DIR .. 'glkcore/io/win32/*', SRC_DIR .. 'glkcore/thread/windows/*' }
		end

	-- This project is for win32 only to allow a standard C-main for Windows applications.
	project 'glkmain'
		kind 'StaticLib'
		flags { 'Symbols' }
		if ( PLATFORM == 'win32' ) then
			files { SRC_DIR .. 'glk/glwin32/GlFramework.cpp', SRC_DIR .. 'glk/glwin32/GlFramework.h' }
			links ( LIBS )
		end
			
    -- This lib contains all the GUI/OpenGL specific items
	project 'glk'
		kind 'SharedLib'
		
		if ( PLATFORM == 'linux' ) then
		    --linkoptions { "-Wl,-soname,glk.so.0" }
		end
		
		flags { 'Symbols' }
		files {
			SRC_DIR .. 'glk/*.cpp',
			SRC_DIR .. 'glk/*.h',
			SRC_DIR .. 'glk/lua/*.cpp',
			SRC_DIR .. 'glk/lua/*.h'
		}

		-- need to add files which are platform specific
		if ( PLATFORM == 'win32' ) then
			files { SRC_DIR .. 'glk/glwin32/*' }
			excludes { SRC_DIR .. 'glk/glwin32/GlFramework.cpp', SRC_DIR .. 'glk/glwin32/GlFramework.h' }
			links { 'glkcore' }
			links ( LIBS )
		elseif ( PLATFORM == 'linux' ) then
			files { SRC_DIR .. 'glk/glx/*' }
		end
	
	-- This lib allows Lua progs to import glk directly.
	project 'luaglk'
		kind 'SharedLib'
		
		flags { 'Symbols' }
		files {
			SRC_DIR .. 'luaglk/*.cpp',
			SRC_DIR .. 'luaglk/*.h',
		}
		
		if ( PLATFORM == 'linux' ) then
		    --linkoptions { "-Wl,-soname,luaglk.so.0" }
		    files { SRC_DIR .. 'luaglk/linux/*.cpp' }
		end
		
		if ( PLATFORM == 'win32' ) then
    	    files { SRC_DIR .. 'luaglk/win32/*.cpp' }
		end
	
		if ( PLATFORM == 'win32' ) then
			links { 'glkcore', 'glk' }
			links ( LIBS )
		end
	
	-- Specify the example projects (glk/examples/):
	project 'hello-world'
		kind 'WindowedApp'
	    flags { 'WinMain' }
				
		libdirs ( LIB_PATHS )
		links { 'glkmain', 'glk', 'glkcore' }
		links ( LIBS )
		
		files { SRC_DIR .. 'examples/hello_world/*.cpp', SRC_DIR .. 'examples/hello_world/*.h' }

    project 'console'
        kind 'WindowedApp'
	    flags { 'WinMain' }
				
		libdirs ( LIB_PATHS )
		links { 'glkmain', 'glk', 'glkcore' }
		links ( LIBS )
						
		files { SRC_DIR .. 'examples/console/*.cpp', SRC_DIR .. 'examples/console/*.h' }

    project 'multi-window'
        kind 'WindowedApp'
	    flags { 'WinMain' }
				
		libdirs ( LIB_PATHS )
		links { 'glkmain', 'glk', 'glkcore' }
		links ( LIBS )
						
		files { SRC_DIR .. 'examples/multi_window/*' }

	project 'alpha-window'
		kind 'WindowedApp'
	    flags { 'WinMain' }
				
		libdirs ( LIB_PATHS )
		links { 'glkmain', 'glk', 'glkcore' }
		links ( LIBS )
			
		files { SRC_DIR .. 'examples/alpha_window/*.cpp', SRC_DIR .. 'examples/alpha_window/*.h' }

    project 'lua-window'
        kind 'WindowedApp'
        flags { 'WinMain' }
				
		libdirs ( LIB_PATHS )
		links { 'glkmain', 'glk', 'glkcore' }
		links ( LIBS )
		
		files { SRC_DIR .. 'examples/lua_window/*.cpp', SRC_DIR .. 'examples/lua_window/*.h' }

    -- unit test project
	project 'utest'
		kind 'ConsoleApp'
				
		libdirs ( LIB_PATHS )
		links { 'glkmain', 'glk', 'glkcore' }
		links ( LIBS )

		files { SRC_DIR .. 'test/*.cpp' }
		
