/**
\page font_tut_page Tutorial 2

\section font_sec Font Rendering using FreeType and OpenGL

GLK uses the freetype library to provide a simple font rendering mechanism. The freetype library is used to create texture mapped fonts that can then be rendered into an OpenGL window (GlWindow).

All the freetype components have been encapsulated in C++ objects within the Ft namespace. The OpenGL font rendering is handled through a single class GLK::GlFont. We can modify the hello world example so that is uses this class to draw some text (edit <em>'examples/hello_world/DerivedClass.h'</em>).

First we need to add Ft::Library and GLK::GlFont objects to the class, so lets add them at the end after the private tag:

\code

class DerivedWindow : public GLK::GlWindow
{
public:

// ...

private:
    // ADD THESE TWO LINES:
    Ft::Library* m_library;
    GLK::GlFont* m_font;      
};

\endcode

If we read GlFont's constructor documentation (GLK::GlFont::GlFont) we see that it needs to be constructed when a valid opengl context is active. The context is active when InitGL() is called, so we create both objects there. Change InitGL() to look like this:

\code

    virtual bool InitGL()
    {
        glClearColor( 1.f, 1.f, 1.f, 1.f );
        
        // Perform other initialisation here...
        
        m_library = new Ft::Library();
        m_font = new GLK::GlFont( *m_library, DEFAULT_FONT );
        
        if ( m_font->FontLoaded() )
        {
                m_font->SetSizePx( 16 );
                return true;
        }
        else
        {
                return false;
        }
    };

\endcode

The DEFAULT_FONT macro names a sensible default font which is very likely to be available on your operating system. For example on windows it is set to "C:\\WINDOWS\\Fonts\\consola.ttf". You can change this to be the (full) path to a font of your choice. If the font-file exists and is supported by freetype then \code m_font->FontLoaded() \endcode  will return true and the pixel size of the loaded font can be set. Setting the pixel size should not be done frequently because it invalidates the glyph cache (see GLK::GlFont::SetSizePx). Note that if false is returned from InitGL() then the window is immediately destroyed (and GLK::GlWindow::DestroyGL is called).

While we are allocating the objects let's remember to delete them when the OpenGL window is destroyed:

\code

    virtual void DestroyGL()
    {
        // ADD THESE TWO LINES:
        delete m_font;
        delete m_library;
    };

\endcode

Now we can actually render some text (this obviously assumes knowledge of OpenGL). Edit Render() to look like this:

\code
    virtual void Render()
    {
        // setup projection, modelview, and viewport
        glMatrixMode( GL_PROJECTION );
        glLoadIdentity();
        glOrtho( 0, GetWidth(), 0, GetHeight(), -1, 1 );        
        
        glMatrixMode( GL_MODELVIEW );
        glLoadIdentity();
        
        glViewport( 0, 0, GetWidth(), GetHeight() );
        
        // set colour and position, then render a string:
        glColor3f( 0, 0, 0 );
        glTranslatef( 32, 32, 0 );
        m_font->RenderString( "Hello World!");

        SwapBuffers();

        glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );
    };
\endcode

If you now compile and run the modified hello world example you should see something like this:

\image html hello_world_1.png "Hello World" width=10cm

\ref mouse_tut_page

*/
