/**
\page hello_tut_page Tutorial 1

\section hello_sec 'Hello World' Application/Tutorial

The simple hello world application that follows can be found in the sub-directory <em>'examples/hello_world'</em>.
It should have been compiled during the GLK library build process.

All GLK applications begin with a standard C main function which should contain
at least one object derived from GLK::GlWindow. The following listing is the main
routine for a simple hello world app:

\code

#include <glkcore.h>
#include <glk.h>

#include "DerivedWindow.h"

using namespace GLK;

int main( int argc, char** argv )
{
    DerivedWindow win( String("Hello World") ); // Create window object, passing the window title into the constructor

    win.Show(); // Make the window visible
    int exitCode = win.StartEventLoop(); // Enter the window's event loop

    return exitCode;
}

\endcode

All the application processing and rendering is handled by the derived window object. A simple derived window class which displays a blank screen could be defined as follows:

\code

#ifndef DERIVED_WINDOW_H
#define DERIVED_WINDOW_H

#include <glkcore.h>
#include <glk.h>

class DerivedWindow : public GLK::GlWindow
{
public:
    DerivedWindow( GLK::String title ) : GlWindow( 10, 10 )
    {
        GlWindow::SetWindowName( title.cStr() );
        GlWindow::Move( 10,10, 320,240 ); // Move window position to (10,10) and resize window to 320x240 pixels
    };

    virtual ~DerivedWindow() {};

    virtual bool InitGL()
    {
        glClearColor( 1.f, 1.f, 1.f, 1.f );
        
        // Perform other initialisation here...
        
        return true; // Must indicate whether initialisation was successful or not.
    };

    virtual void DestroyGL()
    {
    
    };

    virtual void Resize( unsigned int width, unsigned int height )
    {
        // Window has been resized so perform necessary updates...
    };

    virtual bool Update( unsigned int time_ms )
    {
        return true; // Render() only gets called if Update() returns true.
    };

    virtual void Render()
    {
        // Would perform rendering here ...

        SwapBuffers();

        glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );
    };

    virtual void TimerExpired( int timerId ) {};

private:

};

#endif // DERIVED_WINDOW_H

\endcode

It is generally bad practice to put all the code for a class in the header but this is not a C++ programming guide! The following tutorials will build on this example. Compile and run the example to verify that it works as expected. (You can compile the example from the sub-directory <em>'examples/hello_world/linux_build'</em>.

\ref font_tut_page

*/
