
/*! \mainpage GLK (OpenGL ToolKit) Documentation
 
\image html alpha_window.png "Alpha Compositing with GLK" width=5cm
 
\section intro_sec Introduction
 
GLK (OpenGL toolKit) is a cross platform application API/framework/toolkit for creating simple OpenGL applications.
It provides basic facilities for setting up multiple OpenGL windows, handling mouse/keyboard input, rendering
text, and also provides a Lua console (rendered with OpenGL).

It also includes a number of more general purpose classes for file handling and multi-threading amongst others.

It is distributed under the MIT license (see the \ref license_sec section).

This API is designed the way I like things. It is provided 'as is' in terms of both functionality and design.

\subsection platform_sec Supported Platforms
Currently GLK has been tested (in a limited sense) on Linux and Windows platforms. Mac OSX support is not
currently implemented but certainly possible.
 
\subsection start_sec Getting Started
 
You can find installation instructions here: \ref install_page and software dependencies here: \ref ack_page.

(Limited) documentation and tutorials can be found here: \ref refman_page.

The latest version under development is always available using Bazaar:
\code
$ bzr branch lp:glk
\endcode
Launchpad home page: https://launchpad.net/glk

\subsection why_sec Why do I need this?
 
You probably don't. There are many libraries that support OpenGL development, GLUT, SDL, QT, GTK etc.
However, there appears to be a gap for an object oriented C++ API which is simple and limited like
GLUT, but is targetted solely at OpenGL, which SDL, Qt and GTK are not. GLK is intended to fill this
gap.

\section license_sec License

The software and this documentation is distributed under the following MIT License:
 
Copyright © 2006-2010 Mark Pupilli
 
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.
 
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

\page install_page Building and Installation

To build GLK you should first check that you have the required libraries/tools: \ref ack_page
Each dependency can have associated notes so read that page before continuing, even if you
already have all the dependencies installed.

From a shell-console or command-prompt go to the 'glk/builds' directory
and use premake to run the script 'premake4.lua'. The script
will automatically detect your operating system and produce
a build directory 'xxx_build' (where xxx depends on the
opreating system). You can then go into that directory and build
the library. (E.g. on windows you can open the visual studio solution,
on linux you can type 'make', etc.). This will also build the examples
in the sub-directory 'glk/src/examples/'.

If make is unsuccessful then check that paths and
other variables in the script 'configure_xxx.lua' are
suitable for your system. If you change the premake
scripts then do not forget to re-run premake.

\section sec_run_examples RUNNING EXAMPLES

The builds creates shared libraries and example programs. If you want to run
the examples without installing the shared libraries to your usual library
locations then do the following:

On windows the .dll files are in the same directory as the example programs
so they should automatically be found and the programs should just run.

On Linux you can run the examples without installing the .so files as follows:
\code
$ LD_LIBRARY_PATH=./ ./hello-world
\endcode

The linker will then look in the current directory for libs (which is not
the default behaviour on most systems).

\section sec_install INSTALLATION

This is work in progress and currently works for LINUX ONLY.

First build the release and debug versions of GLK:
\code
$ cd glk/builds/linux_build
$ make config=debug & make config=release
\endcode

Then from the 'glk/builds' directory run the install script like so:
\code
$ sudo ./install.sh
\endcode

This will copy the shared libraries and GLK's init.lua file to the
appropraite install dirs.

TODO:
Configurable install dir.
Configure and use proper versioned sonames.

\section sec_bazaar_repo SOURCE FROM BAZAAR REPOSITORY

The latest code under development is always available using Bazaar:
\code
$ bzr branch lp:glk
\endcode

**/
