/*
  This header includes every component of the core framework.
*/

/**
    \namespace Ft
    \brief This is the Free-Type namepsace. All classes which wrap FreeType constructs reside here.

    \namespace Lua
    \brief This is the Lua namepsace. All classes which wrap Lua reside here.
**/

#ifndef FRAMEWORK_CORE_H
#define FRAMEWORK_CORE_H

#define GLK_MAJOR_VERSION 0
#define GLK_MINOR_VERSION 3
#define GLK_MINOR_REVISION 1

#ifdef WIN32
#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#endif

// Multi-Threading support
#include "../src/glkcore/thread/Mutex.h"
#include "../src/glkcore/thread/MutexLock.h"
#include "../src/glkcore/thread/Thread.h"
#include "../src/glkcore/thread/ConditionVariable.h"
#include "../src/glkcore/thread/Semaphore.h"
#include "../src/glkcore/thread/Barrier.h"
#include "../src/glkcore/thread/MessageQueue.h"

// Utilities
#include "../src/glkcore/utility/GlobalDefs.h"
#include "../src/glkcore/utility/Utility.h"
#include "../src/glkcore/utility/String.h"
#include "../src/glkcore/utility/CircularBuffer.h"
#include "../src/glkcore/utility/AutoPtr.h"

// containers
#include "../src/glkcore/containers/List.h"
#include "../src/glkcore/containers/ConstListIterator.h"
#include "../src/glkcore/containers/ListIterator.h"

// date and time
#include "../src/glkcore/time/Timer.h"

// system input/output
#include "../src/glkcore/io/FileUtilities.h"
#include "../src/glkcore/io/StdIn.h"
#include "../src/glkcore/io/StdOut.h"
#include "../src/glkcore/io/File.h"

// Lua (scripting language) support
#include "../src/glkcore/lua/LuaSupport.h"

// Text service
#include "../src/glkcore/free_type/FreeTypeSupport.h"

#endif
