// Copyright (c) Mark Pupilli 2010, All Rights Reserved.

#ifndef ALPHA_WINDOW_H
#define ALPHA_WINDOW_H

#include <glkcore.h>
#include <glk.h>

class AlphaWindow : public GLK::GlWindow
{
public:
    AlphaWindow( GLK::String title ) : GlWindow( 10, 10, GLK::AlphaComposited | GLK::Decorless )
    {
        GlWindow::SetWindowName( title.cStr() );
        GlWindow::Move( 10, 10, 300, 300 ); // Move window position to (10,10) and resize window to 320x240 pixels
    };

    virtual ~AlphaWindow()
    {
    
    };

    virtual bool InitGL()
    {
        glClearColor( 0.f, 0.f, 0.f, 0.f );
        
        // Perform other initialisation here...
        
        m_library = new Ft::Library();
        m_font = new GLK::GlFont( *m_library, DEFAULT_FONT );
        
        if ( m_font->FontLoaded() )
        {
                m_font->SetSizePx( 64 );
                return true;
        }
        else
        {
                return false;
        }
        
    };

    virtual void DestroyGL()
    {
        delete m_font;
        delete m_library;
    };

    virtual void Resize( unsigned int width, unsigned int height )
    {
        // Window has been resized so perform necessary updates...
    };

    virtual bool Update( unsigned int time_ms )
    {
        return true; // Render() only gets called if Update() returns true.
    };

    virtual void Render()
    {
        // setup projection, modelview, and viewport
        glMatrixMode( GL_PROJECTION );
        glLoadIdentity();
        glOrtho( 0, GetWidth(), 0, GetHeight(), 1, -1 );        
        
        glMatrixMode( GL_MODELVIEW );
        glLoadIdentity();
        
        glViewport( 0, 0, GetWidth(), GetHeight() );
        
        // Render text with drop shadow and underline
        glTranslatef( GetWidth()/2.f,GetHeight()/2.f, 0 ); // translate text to centre of window
        glRotatef( 50.f*m_timer.GetSeconds(), 0, 0, 1 ); // time based rotation in screen plane
        float rotPointX = m_font->GetOffsetPx( "ALPHA!", 3 ); // horizontal pivot pont will be immediatley after 'P'
        float rotPointY = m_font->GetSizePx()/2.f; // vertical pivot point is half the line height for this font
        glTranslatef( -rotPointX, -rotPointY, 0.f ); // Translate so text rotates around its centre
        
        // Render a red under-line with a quad:
        glColor4f( 1.f, 0.f, 0.f, 0.3f );
        glBegin( GL_QUADS );
        {
            glVertex2f( -20, -5 );
            glVertex2f( 240, -5 );
            glVertex2f( 240, -20 );
            glVertex2f( -20, -20 );
        }
        glEnd();
        
        // Draw shadow first so that it appears behind:
        glColor4f( 0, 0, 0, 0.6f );
        float dropOffset = -m_font->GetSizePx()/20.f;
        glPushMatrix();
        {
            glTranslatef( dropOffset, dropOffset, 0.f );
            m_font->RenderString( "ALPHA!" );
        }
        glPopMatrix();
                
        // Now render opaque text:
        glColor4f( 0.f, 0.f, 0.5f, 1.f );
        m_font->RenderString( "ALPHA!" );

        SwapBuffers();

        glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );
    };

    virtual void TimerExpired( int timerId ) {};

private:
    Ft::Library* m_library;
    GLK::GlFont* m_font;
    
    GLK::Timer   m_timer;
};

#endif // DERIVED_WINDOW_H


