#include <glkcore.h>
#include <glk.h>

/*
    Simple example which creates a ConsoleWindow object which runs a console
    in a new thread. The main thread then enters a loop which receives commands
    from the console and passes them to the lua interpreter for execution. Output
    and errors appear in the ConsoleWindow.

    Within the console's environment the 'console' object provides the following functions:
    console.font( string ) : Change the console's font.
    console.clear() : Wipes the console's buffer.
    console.exit( int ) : Exit with exit code (also exit(int) works).
    console.fullscreen() : Switch the console window to fullscreen.
    console.windowed() : Switch the console from fullscreen back to a window.
    
    Try entering:
        "for i,v in pairs(console) do print(i,v) end"
    at the lua prompt to list the console's table.
*/
int main( int argc, char** argv )
{
    // Start console
    GLK::ConsoleWindow* console = new GLK::ConsoleWindow( "Lua GL Console", 600, 400, GLK::String(">> ") );

    // Setup Lua
    Lua::LuaState lua;
    lua.OpenLibraries();

    // Set up console to be Lua friendly.
    console->SetupLua( lua );

    // Start loop which processes command-messages from console.
    GLK::String cmd;
    while( console->IsRunning() )
    {
        // First burn through all commands in buffer as fast as possible:
        while ( console->TryCommand( cmd ) )
        {
            int err = lua.DoString( cmd.cStr() );
            lua.PrintError( err, *console );
        }
        
        // Then sleep while buffer is empty so we don't waste cpu time.
        console->WaitCommand();
    }

    int exitCode = console->WaitForClose();

    delete console;

    return exitCode;
}

