// Copyright (c) Mark Pupilli 2010, All Rights Reserved.

#ifndef DERIVED_WINDOW_H
#define DERIVED_WINDOW_H

#include <glkcore.h>
#include <glk.h>

class DerivedWindow : public GLK::GlWindow, public GLK::MouseHandler
{
public:
    DerivedWindow( GLK::String title, const GLK::GlConfig& glConfig ) : GlWindow( 10, 10, GLK::Normal, &glConfig )
    {
        GlWindow::SetWindowName( title.cStr() );
        GlWindow::Move( 10,10, 320,240 ); // Move window position to (10,10) and resize window to 320x240 pixels

        // ADD THIS LINE
        PushMouseHandler( this );
    };

    virtual ~DerivedWindow()
    {
    
    };

    virtual bool InitGL()
    {
        glClearColor( 1.f, 1.f, 1.f, 1.f );
        
        // Perform other initialisation here...
        
        m_library = new Ft::Library();
        m_font = new GLK::GlFont( *m_library, DEFAULT_FONT );
        
        if ( m_font->FontLoaded() )
        {
            m_font->SetSizePx( 16 );
            return true;
        }
        else
        {
            return false;
        }
    };

    virtual void DestroyGL()
    {
        delete m_font;
        delete m_library;
    };

    virtual void Resize( unsigned int width, unsigned int height )
    {
        // Window has been resized so perform necessary updates...
    };

    virtual bool Update( unsigned int time_ms )
    {
        return true; // Render() only gets called if Update() returns true.
    };

    virtual void Render()
    {
        // setup projection, modelview, and viewport
        glMatrixMode( GL_PROJECTION );
        glLoadIdentity();
        glOrtho( 0, GetWidth(), 0, GetHeight(), -1, 1 );        
        
        glMatrixMode( GL_MODELVIEW );
        glLoadIdentity();
        
        glViewport( 0, 0, GetWidth(), GetHeight() );
        
        // set colour and position, then render a string:
        glColor3f( 0, 0, 0 );
        glTranslatef( m_x, m_y, 0 );
        m_font->RenderString( "Hello World!");

        SwapBuffers();

        glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );
    };

    virtual void TimerExpired( int timerId ) {};

    void FileDrop( const char* const fileName )
    {
    }

    void DoubleClick( ButtonId id, int x, int y )
    {
    }
    
    void NewPosition( int x, int y )
    {
        m_x = x;
        m_y = GetHeight() - y;
    }
    
    void ButtonEvent( ButtonId id, bool down )
    {
    }
    
    void Scroll( int delta )
    {
    }
    
    bool WasUpdated()  
    {
        return false;
    }

    void Activated()  
    {
    }
    
    void Deactivated()
    {
    }

private:
    float m_x;
    float m_y;
    Ft::Library* m_library;
    GLK::GlFont* m_font;  
};

#endif // DERIVED_WINDOW_H


