-- Example of using a GLK from Lua.
--
-- This example can be used from a GLK::LuaWindow object or from
-- a standalone LuaGLK program. There are examples in this directory:
--    There is a C++ example in 'main.cpp'.
--    There is a standalone Lua program in 'glk-standalone.lua'.
--
-- You need LuaGL installed for the following script to work: http://luagl.sourceforge.net/

require( "luagl" )

angle = 0.0

-- List the object's table for reference (The 'lua_window' object was created by the C++ program)
function lua_window:InitGL()
    print 'lua_window:InitGL() called'

    gl.ClearColor( 1, 0.5, 0, 0 )

    return true -- Must indicate initialisation was successful otherwise the window will be immediately destroyed.
end

function lua_window:DestroyGL()
    -- nothing to do here in this simple example
    print 'lua_window:DestroyGL() called'
end

function lua_window:Resize( width, height )
    -- setup the viewport
    gl.Viewport(0, 0, width, height)

    gl.MatrixMode( 'PROJECTION' )
    gl.LoadIdentity()            
    
    -- remove use of glu so tutorial relies on fewer bits:
    --glu.Perspective( 80, width / height, 1, 1000 )
    aspect = width/height
    height = 0.84
    width = height*aspect
    gl.Frustum( -width, width, -height, height, 1, 1000 );

    gl.MatrixMode( 'MODELVIEW' )
    gl.LoadIdentity()
end

function lua_window:Update( time_ms )
    angle = angle + time_ms * 0.25
    return true; -- always update (this is bad as it will burn CPU time!)
end

function lua_window:Render()
    gl.ClearColor( 1, 0.5, 0, 0 )
    --gl.ClearColor( 0, 0, 0, 0 )

    -- The following is taken from one of the LuaGL examples:    
    gl.LoadIdentity()              -- Reset The Current Modelview Matrix
    gl.Translate( -1.5, 0, -6 )      -- Move Left 1.5 Units And Into The Screen 6.0

    gl.Begin('TRIANGLES')          -- Drawing Using Triangles
        gl.Vertex( 0,  1, 0)         -- Top
        gl.Vertex(-1, -1, 0)         -- Bottom Left
        gl.Vertex( 1, -1, 0)         -- Bottom Right
    gl.End()                       -- Finished Drawing The Triangle
  
    gl.Translate(3, 0, 0)          -- Move Right 3 Units
    gl.Rotate( angle , 0, 0, 1 )
  
    gl.Begin('QUADS')              -- Draw A Quad
        gl.Vertex(-1,  1, 0)         -- Top Left
        gl.Vertex( 1,  1, 0)         -- Top Right
        gl.Vertex( 1, -1, 0)         -- Bottom Right
        gl.Vertex(-1, -1, 0)         -- Bottom Left
    gl.End()

    self.SwapBuffers() -- call swap buffers on the window object 
    gl.Clear( 'COLOR_BUFFER_BIT,DEPTH_BUFFER_BIT' ) 
end

