#include <assert.h>

#include "ClickWindow.h"

#include <stdlib.h>

/*
    Test creates OpenGL windows which run
    asynchronous event loops and pass mouse-down
	messages to each other. Also tests Lua integration.
*/
int main( int, char** )
{
    GLK::LuaConsole console( 128, 10 );
    Lua::LuaState* lua = console.GetLua();

    lua->OpenLibraries();

    LUA_REGISTER_FUNCTION( lua, createWindow );
    LUA_REGISTER_PRINT( lua );

    // Explicitly create the first window
    g_win[0] = new ClickWindow( 100, 100 );
    g_win[0]->StartEventLoopAsync();
    g_win[0]->Move(0,0);
    g_win[0]->PushKeyboardHandler( &console );

    // Two more windows are created by running the script 'test.lua'.
    // Further windows can be created by typing createWindow( width, height )
    // at the first Window's Lua console.
    lua->DoFile( "../../../src/examples/multi_window/test.lua" );

    // Wait for all window event loops to exit
    for ( unsigned int i=0; i<MAX_WINDOWS ; ++i )
    {
        if ( g_win[i] )
        {
            g_win[i]->WaitForClose();
        }
    }

    // Once all windows have been closed it is safe to delete them
    for ( unsigned int i=0; i<MAX_WINDOWS ; ++i )
    {
        delete g_win[i];
    }

    return 0;
}
