#ifndef BASIC_MOUSE_H
#define BASIC_MOUSE_H

#include "../include/glkcore.h"
#include "MouseHandler.h"

namespace GLK
{

/**
    The most simple mouse handler.

    Intended to speed development of simple programs.
**/
class FW_API BasicMouse : public MouseHandler
{

public:

    BasicMouse() : m_scroll(0), m_scrollChange(0), m_dx(0), m_dy(0), m_dropFile(0), m_active(false), m_updated(false) { m_button[0] = m_button[1] = m_button[2] = false; };
    virtual ~BasicMouse() { ClearDrop(); };

    char* GetDrop() { return m_dropFile; };
    void ClearDrop() { delete [] m_dropFile; m_dropFile=0; };
    virtual void FileDrop( const char* const fileName ) { ClearDrop(); m_dropFile = new char[ strlen(fileName)+1 ]; strcpy(m_dropFile,fileName); m_updated=true; };

    virtual void DoubleClick( ButtonId , int , int  ) {};
    
    void NewPosition( int x, int y )
    {
        m_dx = x - m_x;
        m_dy = y - m_y;
        m_x = x; m_y = y;
        m_updated = true;
    };
        
    void ButtonEvent( ButtonId id, bool state )
    {
        m_button[id] = state;
        m_updated = true;
    };

    void Scroll( int delta ) { m_scrollChange = delta; m_scroll += m_scrollChange; m_updated = true; };

    void Activated()    { m_active = true; };
    void Deactivated()  { m_active = false; };

    int GetScroll() const { return m_scroll; };
    int GetX() const { return m_x; };
    int GetY() const { return m_y; };
    int GetDscroll() const { return m_scrollChange; };
    int GetDx() const { return m_dx; };
    int GetDy() const { return m_dy; };

    bool GetButton( ButtonId id ) const { return m_button[id]; };

    //! Return true if the handler was updated since the last call to WasUpdated().
    bool WasUpdated() { bool tmp = m_updated; m_updated = false; return tmp; };

    void FinishUpdate()
    {
        m_scrollChange = 0;
        m_dx = 0;
        m_dy = 0;
        m_updated = false;
    };

private:
    SET_UNCOPYABLE( BasicMouse )

    int m_scroll;
    int m_scrollChange;
    int m_x;
    int m_y;
    int m_dx;
    int m_dy;
    char* m_dropFile;

    bool m_active;
    bool m_button[3];
    bool m_updated;
};

} // end namespace GLK

#endif // end BASIC_MOUSE_H
