#include "Console.h"

namespace GLK
{

/**
    Create a new console with specified maximum command and history lengths.
    @param commandLength The maximum length of a single command 'typed' into the console.
    @param historyLength The maximum number of elements kept in the history buffer (circular buffer).
**/
Console::Console( unsigned int commandLength, unsigned int historyLength )
:
    m_command ( "", commandLength ),
    m_history ( historyLength ),
    m_updated ( false )
{
}

Console::~Console()
{
}

/**
    Insert characters onto the current line (as if they had been typed into the console).

    The buffer pChars must point to at least numChars characters.

    @param pChars Pointer to the 'typed' characters.
    @param The number of characters to be taken from pChars.

    @return true if an end of line was encountered, false otherwise.
**/
bool Console::Type( const char* pChars, unsigned int numChars )
{
    bool rval = false;

    // Loop through chars, adding into the current command string:
    const char* end = pChars + numChars;
    while ( pChars != end )
    {
        if ( *pChars == '\r' )
        {
            m_command += '\0';
            m_history.Add( m_command );
            m_command.Clear();

#ifdef __linux
            fprintf( stderr, "\n" );
#else
            WriteFile( GetStdHandle(STD_ERROR_HANDLE), "\n", 1, 0, 0 );
#endif
                rval = true;
        }
        else
        {
            m_command += *pChars;
#ifdef __linux
            fprintf( stderr, "%c", *pChars );
#else
            WriteFile( GetStdHandle(STD_ERROR_HANDLE), pChars, 1, 0, 0 );
#endif
        }

        pChars++;
    }

    return rval;
}

void Console::Retrieve( String& , unsigned int )
{

}

} // end namespace GLK

