#ifndef CONSOLE_BUFFER_H
#define CONSOLE_BUFFER_H

#include <stddef.h>
#include <stdarg.h>
#include "../glkcore/utility/GlobalDefs.h"

namespace GLK
{

/**
    Implements a circular text buffer.
    
    Does not use CircularBuffer class because the ConsoleBuffer's
    char array is only losely encapsulated (low level access provided)
    which is not the intention of CircularBuffer.

    TODO: console buffer should allow resizing (and handle it gracefully!) 
**/
class ConsoleBuffer
{
public:
    ConsoleBuffer( size_t cols, size_t rows, size_t lines );
    ~ConsoleBuffer();

    size_t GetCols() const { return m_cols; };
    size_t GetRows() const { return m_rows; };
    size_t GetVisibleSize() const { return m_rows*m_cols; };

    void MoveCursor( int n );
    void Erase( char c = '\0' );
    void Put( char c );
    void WriteText( const char* text, size_t numBytes );
    int  Printf( const char* formatString, va_list args );
    
    void Scroll( int n );
    void Clear();
    
    const char* GetFirstVisibleLine() const { return m_pStart + ((m_viewStart-1) % m_lines)*m_cols; };
    const char* const GetStart() const { return m_pStart; };
    const char* const GetEnd() const   { return m_pEnd; };

protected:

private:
    SET_UNCOPYABLE(ConsoleBuffer)

    void FillChar( char c, int repeat );
    void Write( const char* p, size_t n );

    char* GetLineStart()    { return m_pStart + m_cols*( (m_line-1) % m_lines); };
    char* GetLineEnd()      { return m_pStart + m_cols*(  m_line    % m_lines); };
    void NewLine();
    void AdjustView();

    const size_t m_size;    //< Number of chars in buffer.
    const size_t m_cols;    //< Number of chars visible horizontally.
    const size_t m_rows;    //< Number of chars visible vertically.
    const size_t m_lines;   //< Number of lines stored in text buffer.

    char* const m_pStart;   //< Pointer to start of buffer.
    char* const m_pEnd;     //< Pointer to end of buffer.
    char*       m_cursor;   //< Pointer to the current cursor position.
    int         m_line;
    int         m_viewStart;
};

} // end namespace GLK

#endif // CONSOLE_BUFFER_H
