#ifndef CONSOLE_WINDOW_H
#define CONSOLE_WINDOW_H

#include "../include/glkcore.h"

#include "KeyboardHandler.h"
#include "GlThreadWindow.h"
#include "BasicMouse.h"
#include "ConsoleBuffer.h"

namespace Ft
{

class Library; // fwd decl

}

namespace GLK
{

class GlFont; // fwd decl

/**
    Class for creating a console for any application.
    The console draws into its own window which runs in
    a new thread.

    Funcionality is provided for receiving commands,
    writing text to the console, and reconfiguring the console,
    all of which can be done asynchronously (and in a thread safe manner).
**/
class FW_API ConsoleWindow :  public StdOut, public Lua::LuaObject, public KeyboardHandler, public GlThreadWindow
{
public:
    ConsoleWindow( const char* title, int width, int height, const String& prompt );
    ~ConsoleWindow();

    void SetupLua( Lua::LuaState& lua );
    virtual int Dispatch( lua_State* L, lua_Number );

    bool ChangeFont( const char* fontFile );
    void Clear();

    size_t Write( const char* text, size_t numBytes );
    int Printf( const char* formatString, ... );

    void GetCommand( String& );
    bool TryCommand( String& );
    void WaitCommand();

    void Notify();

    void PasteCommand( const String& );

    // KeyboardHandler Interface:
    virtual void Key( char c );
    virtual bool WasUpdated()   { bool tmp = m_update; m_update = false; return tmp; };
    virtual void Activated()    {};
    virtual void Deactivated()  {};

protected:

private:
    SET_UNCOPYABLE( ConsoleWindow )

    static int font( const Lua::LuaState& lua, ConsoleWindow* console );
    static int consolePrint( lua_State* L );

    static const size_t m_kNumLines = 128;

    // GlThreadWindow Interface:
    virtual bool InitGL();
    virtual void DestroyGL();
    virtual void Resize(unsigned int, unsigned int );
    virtual bool Update(unsigned int);
    virtual void Render();
    virtual void TimerExpired( int id );

    bool GlFontSetup();

    ConsoleBuffer* m_buffer;
    Ft::Library* m_library;
    GlFont*      m_font;

    float m_monoSpace;

    BasicMouse m_mouse;
    Mutex m_mutex;
    const String m_prompt;

    String m_command;
    unsigned int m_cmdPos;

    List<String>            m_history;
    ListIterator<String>    m_histItr;

    MessageQueue<String>    m_msg;
    bool m_update;
    bool m_blink;

    bool m_quitting;
};

} // end namespace GLK

#endif // CONSOLE_WINDOW_H
