#include "GlConfig.h"

namespace GLK
{

/**
    Create a GlConfig object with default settings.
**/
GlConfig::GlConfig()
:
    m_red       (8),
    m_green     (8),
    m_blue      (8),
    m_alpha     (0),
    m_depth     (24),
    m_stencil   (0),
    m_doubleBuffered ( true )
{
}

/**
    Create a config which is an exact copy of the specified config.
**/
GlConfig::GlConfig( const GlConfig& config )
:
    m_red       (config.m_red),
    m_green     (config.m_green),
    m_blue      (config.m_blue),
    m_alpha     (config.m_alpha),
    m_depth     (config.m_depth),
    m_stencil   (config.m_stencil),
    m_doubleBuffered (config.m_doubleBuffered)
{   
}

/**
    Nothing to do.
**/
GlConfig::~GlConfig()
{
    
}

/**
    Set the desired minimum number of bits for the red framebuffer channel.
    
    Default: 8 bit
**/
void GlConfig::SetRedSize( unsigned int size )
{
    m_red = size;
}

/**
    Set the desired minimum number of bits for the red framebuffer channel.
    
    Default: 8 bit
**/
void GlConfig::SetGreenSize( unsigned int size )
{
    m_green = size;
}

/**
    Set the desired minimum number of bits for the red framebuffer channel.
    
    Default: 8 bit
**/
void GlConfig::SetBlueSize( unsigned int size )
{
    m_blue = size;
}

/**
    Set the desired minimum number of bits for the red framebuffer channel.
    
    Default: 8 bit
**/
void GlConfig::SetAlphaSize( unsigned int size )
{
    m_alpha = size;
}

/**
    Set the desired minimum number of bits for the red framebuffer channel.
    
    Default: 32 bit
**/
void GlConfig::SetDepthSize( unsigned int size )
{
    m_depth = size;
}

/**
    Set the desired minimum number of bits for the red framebuffer channel.
    
    Default: 0 bit
**/
void GlConfig::SetStencilSize( unsigned int size )
{
    m_stencil = size;
}

/**
    Set whether the frame buffer should be double buffered or not.
    @parm b True is double buffering is desired, false if single buffering is required.
**/
void GlConfig::SetDoubleBuffered( bool b )
{
    m_doubleBuffered = b;
}

/**
    Print a string representation of the config to a file.
**/
void GlConfig::Show( FILE* fp )
{
    fprintf( fp, "RGBA %d%d%d%d DEPTH %d STENCIL %d DOUBLEBUFFERED %d\n",
                m_red, m_green, m_blue, m_alpha, m_depth, m_stencil, m_doubleBuffered );
}

} // end of namespace GLK

