#ifndef GL_CONFIG_H
#define GL_CONFIG_H

#include "../glkcore/fwconfig.h"

#include <stdio.h>

namespace GLK
{

/**
    Class for describing an OpenGL framebuffer configuration.
    
    Can be used to return and query a configuration which is use,
    or to specify a desired configuration in the GLK::GlWindow constructor.
**/
class FW_API GlConfig
{
public:
    GlConfig();
    GlConfig( const GlConfig& config );
    ~GlConfig();
    
    void SetRedSize     ( unsigned int size );
    void SetGreenSize   ( unsigned int size );
    void SetBlueSize    ( unsigned int size );
    void SetAlphaSize   ( unsigned int size );
    void SetDepthSize   ( unsigned int size );
    void SetStencilSize ( unsigned int size );
    void SetDoubleBuffered( bool b );
    
    unsigned int GetRedSize()     const { return m_red; };
    unsigned int GetGreenSize()   const { return m_green; };
    unsigned int GetBlueSize()    const { return m_blue; };
    unsigned int GetAlphaSize()   const { return m_alpha; };
    unsigned int GetDepthSize()   const { return m_depth; };
    unsigned int GetStencilSize() const { return m_stencil; };
    bool IsDoubleBuffered() const { return m_doubleBuffered; };
    
    void Show( FILE* fp = stdout );

private:
    unsigned int m_red;
    unsigned int m_green;
    unsigned int m_blue;
    unsigned int m_alpha;
    unsigned int m_depth;
    unsigned int m_stencil;
    bool         m_doubleBuffered;

};

} // end of namespace Glk

#endif // GL_CONFIG_H

