#ifndef GL_FONT_H
#define GL_FONT_H

#include "../glkcore/free_type/FreeTypeSupport.h"

#ifdef WIN32

#define WIN32_MEAN_AND_LEAN
#include <windows.h>

#ifndef DEFAULT_FONT
#define DEFAULT_FONT "C:\\WINDOWS\\Fonts\\consola.ttf"
#endif

#endif

#ifdef __linux

#ifndef DEFAULT_FONT
#define DEFAULT_FONT "/usr/share/fonts/truetype/ttf-dejavu/DejaVuSansMono.ttf"
#endif

#endif

#include <GL/gl.h>


namespace GLK
{

/**
    Class that allows rendering of Freetype2 fonts
    using OpenGl. The fonts are rendered as bitmaps/textures.
**/
class FW_API GlFont
{
public:
    GlFont( Ft::Library& lib, const char* font, FT_Long index = 0 );
    ~GlFont();

    void SetSizePx( int size );
    int GetSizePx() const { return m_sizePx; };
    float GetLineHeightPx() const { return m_fontFace->GetSize()->metrics.height / 64.f; };
    Ft::Face& GetFace() const { return *m_fontFace; };

    bool FontLoaded() const { return m_fontFace->LoadSuccessful(); };
    bool ChangeFont( const char* font );
    void FillCache();

    void RenderString( const char* pStr, bool useKerning=true );
    void RenderText( const char* pStr, size_t numChars, bool useKerning=true );
    void RenderConsole( const char* pStr, size_t cols, size_t rows, const char* const start, const char* const split, bool useKerning=true );

    float GetOffsetPx(  const char* pStr, unsigned int i, bool useKerning = true );

    static void RenderGlyph( const Ft::Glyph& glyph, int sizePx, unsigned int i );

protected:
    
private:
    SET_UNCOPYABLE(GlFont)

    Ft::Library& m_freeType;
    Ft::Face*    m_fontFace;
    int          m_sizePx;
    
    Ft::Glyph**     m_cache;
    GLuint          m_listIndex; 
    GLuint          m_tabTex;

    void StartGlTexture();
    void StopGlTexture();
    void CreateGlTableau();

    Ft::Glyph& GetGlyph( unsigned char c );
    void InitCache();
    void ClearCache();
    void CacheGlyph( unsigned int i );
};

} // end of namespace GLK

#endif // GL_FONT_H
