#include "GlThreadWindow.h"

namespace GLK
{

/**
	Simply contructs the base class, setting the parameter for delayed initialisation of window resources.
	The delayed initialisation is required because Window resources generally need to be created in the
	same thread that the event loop executes in.
**/
GlThreadWindow::GlThreadWindow( unsigned int w, unsigned int h, int flags, const GlConfig* const glConfig )
:
    GlWindow    ( w, h, flags | Async, glConfig ), // add 'Async' to flags, pass other parameters through unchanged
    m_exitCode  ( -1 )
{
    
}

GlThreadWindow::~GlThreadWindow()
{
    
}

/**
    Starts a seperate thread which runs the windows event loop.
**/
void GlThreadWindow::StartEventLoopAsync()
{
    Thread::Start();
}

/**
    Wait for the window to exit its event loop.
    (Performs a Join() on the thread which is running the event loop).

    @return The windows' exit code as returned from StartEventLoop().
**/
int GlThreadWindow::WaitForClose()
{
    Thread::Join();
    return m_exitCode;
}

/**
	The thread's Run method. Executes the window's event loop.
	If you redefine this method in any derived classes you
	must call GlWindow::StartEventLoop().
**/
void GlThreadWindow::Run()
{
    m_exitCode = GlWindow::StartEventLoop();
}

} // end of namespace GLK
