#ifndef GL_THREAD_WINDOW_H
#define GL_THREAD_WINDOW_H

#include "../glkcore/fwconfig.h"
#include "../glkcore/thread/Thread.h"
#include "GlWindow.h"

namespace GLK
{

/**
	A version of GlWindow which can run its event loop in a seperate thread
	(an asynchronous event loop).

	Protected inheritance from Thread avoids an unecessary intermediate
	class (which would itself have to derive from Thread) and hides Thread's
	interface. An instance of GlThreadWindow should never be treated as if
	its type were Thread.
**/
class FW_API GlThreadWindow : public GlWindow, protected Thread
{
public:
    GlThreadWindow( unsigned int w, unsigned int h, int windowType = Normal, const GlConfig* const glConfig = 0 );
    virtual ~GlThreadWindow();

    void StartEventLoopAsync();
    int WaitForClose();

    bool IsRunning() const { return Thread::IsRunning(); };

protected:
    virtual void Run();

private:
    int m_exitCode;

};

} // End of namespace GLK

#endif // GL_THREAD_WINDOW_H
