#ifndef KEYBOARD_HANDLER_H
#define KEYBOARD_HANDLER_H

#include "../glkcore/fwconfig.h"

namespace GLK
{

/**
    Abstract interface for all keyboard handling classes to derive from.
    The interface has a function for receiving a Key press event,
    but also functions for notifying the handler when it becomes the
    active keyboard handler, and also when it is deactivated.

    Implementation of WasUpdated() is very important. Please implement it properly.
**/
class FW_API KeyboardHandler
{
public:
    KeyboardHandler() {};

    virtual ~KeyboardHandler() {};

    virtual void Key( char c ) = 0; // Called when the window system detects a keyevent
    virtual bool WasUpdated()   = 0; // Must return true if handler was updated (if Key() was called) since last call to WasUpdated().

    virtual void Activated()   = 0; // Notify this handler that it has become active.
    virtual void Deactivated() = 0; // Notify this handler that it has been deactivated.
};

} // end namespace GLK

#endif // ifndef KEYBOARD_HANDLER_H
