#include "LuaConsole.h"

namespace GLK
{

/**
    Constructs base class Console and LuaState m_lua.
**/
LuaConsole::LuaConsole( unsigned int commandLength, unsigned int historyLength )
:
    Console( commandLength, historyLength ),
    m_active    ( false )
{

}

LuaConsole::~LuaConsole()
{

}

void LuaConsole::Key( char c )
{
    Type( &c, 1 );
    Console::Updated();
}

/**
    Receive characters as if they are typed into a console,
    upon encountering a new line execute the line as a lua statement.
**/
bool LuaConsole::Type( const char* pChars, unsigned int numChars )
{
    bool rval = Console::Type( pChars, numChars );
    // first call Type from base class to accumulate command
    if ( rval )
    {
        int error = m_lua.DoString( m_history[ m_history.HeadIndex()].cStr() );

        if ( error == 0 )
        {
            m_lua.GetGlobal( "name" );
            size_t strLength;
            const char* name = m_lua.ToString( -1, &strLength );

            int Kbytes = m_lua.Gc( LUA_GCCOUNT, 0 );
            char buff[64];
            sprintf( buff, "Lua is using %d Kbytes\n", Kbytes );

            if ( strLength )
            {
#ifdef __linux
                fprintf( stderr, "%s\n", buff );
                fprintf( stderr, "%s\n", name );
#else
                WriteFile(GetStdHandle(STD_ERROR_HANDLE), buff, strlen(buff), 0 ,0 );

                WriteFile( GetStdHandle(STD_ERROR_HANDLE), name, strLength, 0, 0 );
                WriteFile( GetStdHandle(STD_ERROR_HANDLE), "\n", 1, 0, 0 );
#endif
            }
        }
        else
        {
            switch ( error )
            {
            case LUA_ERRSYNTAX:
            fprintf(stderr,"SYNTAX ERROR!\n");
                //WriteFile( GetStdHandle(STD_ERROR_HANDLE), "Syntax Error\n", 13, 0, 0 );
                break;
            case LUA_ERRMEM:
                //WriteFile( GetStdHandle(STD_ERROR_HANDLE), "Memory Error\n", 13, 0, 0 );
                break;
            }
        }
    }

    return rval;
}

} // end namespace GLK

