#ifndef MOUSE_HANDLER_H
#define MOUSE_HANDLER_H

#include "../glkcore/fwconfig.h"

namespace GLK
{

/**
    Abstract interface for all mouse handling classes to derive from.
**/
class FW_API MouseHandler
{
public:
    enum ButtonId
    {
        Left    = 0,
        Right   = 1,
        Middle  = 2
    };

    MouseHandler() {};
    virtual ~MouseHandler() {};

    virtual void FileDrop( const char* const fileName ) = 0;
    virtual void DoubleClick( ButtonId id, int x, int y ) = 0;
    virtual void NewPosition( int x, int y ) = 0;
    virtual void ButtonEvent( ButtonId id, bool down ) = 0;
    virtual void Scroll( int delta ) = 0;
    virtual bool WasUpdated()   = 0; // Must return true if handler was updated (any of above 3 methods called) since last call to WasUpdated().

    virtual void Activated()   = 0; // Notify this handler that it has become active.
    virtual void Deactivated() = 0; // Notify this handler that it has been deactivated.
};

} // end namespace GLK

#endif // MOUSE_HANDLER_H
