#include "LuaStandAlone.h"

static GLK::LuaWindow* g_window = 0;
static Lua::LuaState*  g_lua = 0;

/**
    Create a new glk window object.
    
    Expects 3 to 5 arguments:
    1: window title  (STRING)
    2: window width  (INTEGER)
    3: window height (INTEGER)
    4: window flags  OPTIONAL (INTEGER) 
    5: OpenGL frame buffer configuration (TABLE)

    Returns 1 result.
    1:  Reference to the window's table  (TABLE)
**/
FW_API int NewWindow( lua_State* L )
{
    g_lua = new Lua::LuaState( L );
    
    int nargs = g_lua->GetStackSize();
    assert( nargs >= 3 );

    // Check args:
    if ( nargs >= 3 && g_lua->IsString(1) && g_lua->IsNumber(2) && g_lua->IsNumber(3) )
    {
        GLK::String windowName( g_lua->ToString(1) );
        int width = g_lua->ToInteger(2);
        int height = g_lua->ToInteger(3);
        
        g_window = new GLK::LuaWindow( *g_lua, windowName, width, height );
        
        g_window->GetLuaObject(); // Leave the window on top of the stack
        return 1;
    }
    
    return 0;
}

/**
    Delete a named glk window object.
    
    @todo Need proper multi-window registry system for luaglk - implement a window registry in Lua?
**/
FW_API int DeleteWindow( lua_State* L )
{
    Lua::LuaState lua( L );

    // Check args:
    if ( lua.IsString(1) )
    {
        delete g_window;
        delete g_lua;
        g_window = 0;
        g_lua = 0;
    }

    return 0;
}

