#ifndef GLK_LUA_WINDOW_H
#define GLK_LUA_WINDOW_H

#include "../../glkcore/utility/String.h"
#include "../../glkcore/lua/LuaState.h"
#include "../../glkcore/lua/LuaObject.h"
#include "../GlThreadWindow.h"

extern "C"
{
int DynamicLoadTest();
}

namespace GLK
{

/**
    Class which allows access, creation, and control of a GlWindow from Lua
    scripts. We can then use LuaGL (for example) to render from Lua.
    
    The class inherits from a GlThreadedWindow. Hence, a LuaWindow's event
    loop runs in its own thread.
**/
class FW_API LuaWindow : public GlThreadWindow, public Lua::LuaObject
{
public:

    LuaWindow( Lua::LuaState& lua, const String& objectName, unsigned int w, unsigned int h, int windowType = Normal, const GlConfig* const glConfig = 0 );
    ~LuaWindow();
   
    // OpenGL interface will be overidden with calls to Lua functions:
    virtual bool InitGL();
    virtual void DestroyGL();
    virtual void Resize( unsigned int, unsigned int ) ;
    virtual bool Update( unsigned int ) ;
    virtual void Render()               ;
    virtual void TimerExpired( int id ) ;

    // LuaObject interface:
    virtual int Dispatch( lua_State* L, lua_Number id );
  
protected:
    void RegisterMethods();

private:
    String m_name;
};

} // end namespace GLK

#endif // GLK_LUA_WINDOW_H

