#ifndef GLK_FILE_H
#define GLK_FILE_H

#include "../fwconfig.h"

#include <stdio.h>

#include "StdIO.h"

#include "../utility/String.h"

namespace GLK
{

/**
    File handling class.
    
    The file is opened upon construction and closed on
    destruction of the File object.Trying to perform any
    operation on an unopened file is an error (raises an
    assert in debug mode). Always check IsOpen() if there
    is a possibility that the file failed to open.

    Currently just a wrapper around stdio.
**/
class FW_API File : StdIO
{

public:
    File( const char* name, const char* mode );
    ~File();

    size_t Write( const char* buffer, size_t numBytes );
    int Printf( const char* formatString, ... );
        
    size_t Read( char* buffer, size_t numBytes );
    int Scanf( const char* formatString, ... );

    size_t ReadLine( char* buffer, size_t maxBytes );

    bool IsOpen() const { return fp != 0; };

    void Rewind() { rewind(fp); };

    size_t ToString( String& s );

    static bool FileToString( const String& fileName, String& fileContents );

    static void Test();

private:
    FILE* fp;

};

} // end namespace GLK

#endif // GLK_FILE_H
