#include "FileUtilities.h"

#include <sys/types.h>
#include <sys/stat.h>
#include <time.h>

namespace GLK
{

/**
   Get a string containing the human read-able modification timestamp
   of a file. A pointer is returned to a string which is statically
   allocated by the system (and is usually shared by asctime(),
   ctime(), localtime(), and gmtime() - hence calling any of these
   functions may modify the string's contents)).

   Returns null if the file could not be 'statted' (in which case
   stat() sets errno).
**/
char* GetFileModTimeStamp(const char* const fileName)
{
  struct stat fst;
  if ( stat( fileName, &fst ) == 0 )
  {
	  return asctime( localtime( &fst.st_mtime ) );
  }
  return 0;
}

}
