#ifndef GLK_STD_OUT_CLASS_H
#define GLK_STD_OUT_CLASS_H

#include "../fwconfig.h"

#include <stdlib.h>

namespace GLK
{
    
/**
    Abstract class defining a standard output
    interface for classes to derive from. The
    interface is designed to mimic stdio from C.

    The interface is minimal - some classes only
    require a simple read/write interface without
    all the other complexity usually associated
    with streams (e.g flushing, re-positioning etc.)
    It is desirable that such classes be comaptible
    with more complex IO classes.
**/
class FW_API StdOut
{
public:
    StdOut() {};
    virtual ~StdOut() {};

    //! Formatted print
    //! @return The number of bytes printed.
    virtual int Printf( const char* formatString, ... ) = 0;

    //! Write a specified number of bytes from a buffer.
    //! @return The number of bytes successfully written.
    virtual size_t Write( const char* buffer, size_t numBytes ) = 0;
};

} // end namepsace GLK

#endif // GLK_STD_OUT_CLASS_H
