#ifndef GLK_MUTEX_LOCK_H
#define GLK_MUTEX_LOCK_H

#include "Mutex.h"
#include "../utility/GlobalDefs.h"

namespace GLK
{

/**
   Very simple class for reliably locking a mutex.
   The mutex is locked in the constructor and unlocked in the destructor.
   If the mutex is already locked the constructor blocks until the mutex
   is available for locking.

   Can be used to avoid keeping track of mutexes in complex flow control:
   the mutex is automatically unlocked when the MutexLock object goes out of scope.
**/
class FW_API MutexLock
{
 public:
  //! Locks the specified mutex.
  MutexLock( Mutex& m ) : m_mutex(m) { m_mutex.Lock(); };
  ~MutexLock() { m_mutex.Unlock(); };

 private:
  SET_UNCOPYABLE( MutexLock );

  Mutex& m_mutex;
};

}

#endif // GLK_MUTEX_LOCK_H
