#ifndef GLK_POSIX_THREAD_H
#define GLK_POSIX_THREAD_H

#include "../../fwconfig.h"

#include <pthread.h>

#include "../../utility/GlobalDefs.h"

namespace GLK
{

/**
	Abstract thread class.
	This particluar version is implemented as
    a wrapper for pthreads so can be used on
    any operating system that supports posix threads.

	The virtual Run() method gets executed
	concurrently when Start() is called.
**/
class FW_API Thread
{
	friend class Mutex;

public:
    static void Test( void );

    Thread ();
    virtual ~Thread();

    void Start();
    bool Stop();
    bool Join() const;
    void Kill();
    void RequestTermination();
    bool IsRunning() const;
    bool operator == ( const Thread& t ) const;

    static void Sleep( unsigned int msecs );

protected:
    //! Thread behaviour is defined in the Run() method of derived classes.
    virtual void Run() = 0;

    //! To be used internally by Run() method to check for termination requests.
    bool TerminationRequested() { return m_termReq; };

private:
    SET_UNCOPYABLE(Thread);

    pthread_t m_id;
    bool m_running;
    volatile bool m_termReq;

    static void* ThreadStarter( void* );
};

} // END namespace GLK

#endif // GLK_POSIX_THREAD_H
