#ifndef GLK_WIN_THREAD_H
#define GLK_WIN_THREAD_H

#define WIN32_LEAN_AND_MEAN
#include <windows.h>

#include "../../fwconfig.h"
#include "../../utility/GlobalDefs.h"

namespace GLK
{

/**
	Abstract thread class.
	
	This is a wrapper around a native Windows thread.

	The virtual Run() method gets executed
	concurrently when Start() is called.
**/
class FW_API Thread
{
	friend class Mutex;

public:
    static void Test( void );

    Thread ();
    virtual ~Thread();

    void Start();
    bool Stop();
    bool Join() const;
    void Kill();
    void RequestTermination();
    bool IsRunning() const;
    bool operator == ( const Thread& t ) const;

    static void Sleep( unsigned int msecs );

protected:
    //! Thread behaviour is defined in the Run() method of derived classes.
    virtual void Run() = 0;

    //! To be used internally by Run() method to check for termination requests.
    bool TerminationRequested() { return m_termReq; };

private:
    SET_UNCOPYABLE(Thread);

    HANDLE m_handle;
    bool m_running;
    volatile bool m_termReq;

    static DWORD WINAPI ThreadStarter( LPVOID lpParam );
};

} // END namespace GLK

#endif // GLK_THREAD_H
