#ifndef WINDOWS_TIMER_H
#define WINDOWS_TIMER_H

#include "../fwconfig.h"

#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <mmsystem.h>

namespace GLK
{

class FW_API Timer
{
public:
    inline Timer();

    inline void Reset();
    inline float GetSeconds() const;
    inline unsigned int GetMilliSeconds() const;

private:
    DWORD m_init;
};

/**
   Construct a timer.
   Calls Reset(), so subsequent calls to
   GetSeconds() return time since object
   construction.
**/
Timer::Timer()
{
  Reset();
}

/**
   Reset the timer.
**/
void Timer::Reset()
{
  m_init = timeGetTime();
}

/**
    Returns the time since Reset() was last called.
    If no call to Reset() has been made then the
    return value is the time elapsed since the object
    was created.

    @return The time elapsed in seconds. 
**/
float Timer::GetSeconds() const
{
  DWORD current = timeGetTime();
  
  DWORD usecs = current - m_init;

  return 0.001f * usecs;
}

/**
    Returns the time since Reset() was last called.
    If no call to Reset() has been made then the
    return value is the time elapsed since the object
    was created.

    @return The elapsed time in milliseconds.
**/
unsigned int Timer::GetMilliSeconds() const
{
    return timeGetTime() - m_init;
}

} // end namespace GLK

#endif // end WIN_TIMER_H

