#ifndef AUTO_PTR
#define AUTO_PTR

namespace GLK
{

/**
    An managed-pointer class based upon the STL auto_ptr
    (This framework is intended for environments where
    STL is unavailable or undesirable).
**/
template <class T>
class AutoPtr
{
public:
    AutoPtr( AutoPtr& );
    AutoPtr( T* );
    AutoPtr();

    template <class Y> AutoPtr( AutoPtr<Y>& );
    template <class Y>  AutoPtr& operator=( AutoPtr<Y>& );
    ~AutoPtr();

    T& operator*()  const { return *m_ptr; };
    T* operator->() const { return  m_ptr;  };

    T* Get() const { return m_ptr; };
    T* Release();
    void Reset( T* p = 0 );

    // cast
    template <class Y> operator AutoPtr<Y>();

protected:

private:
    T* m_ptr;
};

/**
    All Auto pointers are initialised to be null.
**/
template <class T>
AutoPtr<T>::AutoPtr()
:
    m_ptr (0)
{

}

template <class T>
AutoPtr<T>::AutoPtr( T* p )
:
    m_ptr (p)
{

}

/**
    Free the memory referenced by the pointer.
**/
template <class T>
AutoPtr<T>::~AutoPtr()
{
    delete m_ptr;
}

} // End namespace GLK

#endif // AUTO_PTR

