#ifndef FW_CIRCULAR_BUFFER_H
#define FW_CIRCULAR_BUFFER_H

#include "../utility/GlobalDefs.h"

namespace GLK
{

/**
	Circular buffer of generic type.

	Abstracts an array that has wrap around indexing.
**/
template <class T>
class FW_API CircularBuffer
{
public:
	explicit CircularBuffer( unsigned int capacity );
	virtual ~CircularBuffer();

    const T& operator [] ( unsigned int i ) const { return m_pData[ i % m_capacity ]; };
	T& operator [] ( unsigned int i ) { return m_pData[ i % m_capacity ]; };

    unsigned int Capacity() const { return m_capacity; };
    unsigned int HeadIndex() const { return m_head; };
	unsigned int TailIndex() const { return m_tail; };

    const T& Head() const { return m_pData[m_head]; };
    const T& Tail() const { return m_pData[m_tail]; };

	void Add( T element );
	bool IsFull() const { return (m_head+1)%m_capacity == m_tail; };

private:
	SET_UNCOPYABLE( CircularBuffer );

	const unsigned int m_capacity;
	unsigned int m_head;
	unsigned int m_tail;
	T* m_pData;
};

template <class T>
CircularBuffer<T>::CircularBuffer( unsigned int capacity )
:
	m_capacity	(capacity),
	m_head	(0),
	m_tail	(0),
	m_pData	(0)
{
	m_pData = new T[m_capacity];
}

template <class T>
CircularBuffer<T>::~CircularBuffer()
{
	delete [] m_pData;
}

template <class T>
void CircularBuffer<T>::Add( T element )
{
	m_head = (m_head + 1) % m_capacity;

	if ( m_head == m_tail )
	{
		m_tail = (m_tail + 1) % m_capacity;
	}

    m_pData[m_head] = element;
}

} // end of namespace GLK

#endif
