#include "glk.h"
#include "libluaglk.h"

extern "C"
{
#include <lauxlib.h>
}

#define LUA_IMPORT_NAME "glk"

LUALIB_API __declspec(dllexport) int luaopen_luaglk( lua_State *L )
{
    HMODULE h = LoadLibrary( "glk.dll" );
    if ( h != NULL )
    {
        typedef int(*LuaFuncType)(lua_State*);
        LuaFuncType NewWindow    = (LuaFuncType)GetProcAddress( h, "NewWindow" );
        LuaFuncType DeleteWindow = (LuaFuncType)GetProcAddress( h, "DeleteWindow" );

        if ( NewWindow == NULL || DeleteWindow == NULL )
        {
            return 0;
        }

        // Register the API with the glk library object:
        static const luaL_reg libglk[] = {
            { "NewWindow", NewWindow },
            { "DeleteWindow", DeleteWindow },
            { NULL, NULL}
        };

        luaL_register( L, LUA_IMPORT_NAME, libglk );
    
        // Set some non-function fields e.g. version numbers etc:
        lua_pushnumber( L, GLK_MAJOR_VERSION );
        lua_setfield( L, -2, "major_version" );
        lua_pushnumber( L, GLK_MINOR_VERSION );
        lua_setfield( L, -2, "minor_version" );

        return 1;
    }

    return 0;
}
